==> jc-1.4.0.tar.gz: org/xml/sax/helpers/NewInstance.h <==
// class org.xml.sax.helpers.NewInstance

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d65e4fd26e798005 org_xml_sax_helpers_NewInstance

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_xml_sax_helpers_NewInstance_H_
#define _JC_org_xml_sax_helpers_NewInstance_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_xml_sax_helpers_NewInstance$sub_refs	_jc_org_xml_sax_helpers_NewInstance$sub_refs;
typedef struct _jc_org_xml_sax_helpers_NewInstance$sub_nonrefs	_jc_org_xml_sax_helpers_NewInstance$sub_nonrefs;
typedef struct _jc_org_xml_sax_helpers_NewInstance$refs	_jc_org_xml_sax_helpers_NewInstance$refs;
typedef struct _jc_org_xml_sax_helpers_NewInstance$nonrefs	_jc_org_xml_sax_helpers_NewInstance$nonrefs;
typedef struct _jc_org_xml_sax_helpers_NewInstance$object	_jc_org_xml_sax_helpers_NewInstance$object;

typedef struct _jc_org_xml_sax_helpers_NewInstance$fields_struct	_jc_org_xml_sax_helpers_NewInstance$fields_struct;
typedef const struct _jc_org_xml_sax_helpers_NewInstance$vmethods	_jc_org_xml_sax_helpers_NewInstance$vmethods;
typedef const struct _jc_org_xml_sax_helpers_NewInstance$vtable	_jc_org_xml_sax_helpers_NewInstance$vtable;
typedef const struct _jc_org_xml_sax_helpers_NewInstance$vtype	_jc_org_xml_sax_helpers_NewInstance$vtype;

// Class fields structure
struct _jc_org_xml_sax_helpers_NewInstance$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Thread;
	struct _jc_java_lang_Class$object	*class__24org__24xml__24sax__24helpers__24NewInstance;
};
extern _jc_org_xml_sax_helpers_NewInstance$fields_struct _jc_org_xml_sax_helpers_NewInstance$class_fields;

// Constructors
extern void _jc_org_xml_sax_helpers_NewInstance$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_helpers_NewInstance$object *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_xml_sax_helpers_NewInstance$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_lang_ClassLoader$object *_jc_org_xml_sax_helpers_NewInstance$method$getClassLoader$2078dc747ca30d6e(_jc_env *);
extern struct _jc_java_lang_Object$object *_jc_org_xml_sax_helpers_NewInstance$method$newInstance$29038c6392efb104(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_xml_sax_helpers_NewInstance$vmethods {
};

// Vtable
struct _jc_org_xml_sax_helpers_NewInstance$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_NewInstance$vmethods	org_xml_sax_helpers_NewInstance;
};

// Vtype
struct _jc_org_xml_sax_helpers_NewInstance$vtype {
	_jc_type			type;
	_jc_org_xml_sax_helpers_NewInstance$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_NewInstance$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_helpers_NewInstance$refs {
    _jc_org_xml_sax_helpers_NewInstance$sub_refs	org_xml_sax_helpers_NewInstance;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_NewInstance$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_helpers_NewInstance$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_NewInstance$sub_nonrefs	org_xml_sax_helpers_NewInstance;
};

// Object instance structure
struct _jc_org_xml_sax_helpers_NewInstance$object {
	_jc_org_xml_sax_helpers_NewInstance$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_helpers_NewInstance$vtype	*vtype;
	_jc_org_xml_sax_helpers_NewInstance$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_helpers_NewInstance$vtype _jc_org_xml_sax_helpers_NewInstance$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_helpers_NewInstance, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_helpers_NewInstance$class_object;

#endif	/* _JC_org_xml_sax_helpers_NewInstance_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/helpers/NewInstance.h <==
// class org.xml.sax.helpers.NewInstance

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d65e4fd26e798005 org_xml_sax_helpers_NewInstance

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_xml_sax_helpers_NewInstance_H_
#define _JC_org_xml_sax_helpers_NewInstance_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_xml_sax_helpers_NewInstance$sub_refs	_jc_org_xml_sax_helpers_NewInstance$sub_refs;
typedef struct _jc_org_xml_sax_helpers_NewInstance$sub_nonrefs	_jc_org_xml_sax_helpers_NewInstance$sub_nonrefs;
typedef struct _jc_org_xml_sax_helpers_NewInstance$refs	_jc_org_xml_sax_helpers_NewInstance$refs;
typedef struct _jc_org_xml_sax_helpers_NewInstance$nonrefs	_jc_org_xml_sax_helpers_NewInstance$nonrefs;
typedef struct _jc_org_xml_sax_helpers_NewInstance$object	_jc_org_xml_sax_helpers_NewInstance$object;

typedef struct _jc_org_xml_sax_helpers_NewInstance$fields_struct	_jc_org_xml_sax_helpers_NewInstance$fields_struct;
typedef const struct _jc_org_xml_sax_helpers_NewInstance$vmethods	_jc_org_xml_sax_helpers_NewInstance$vmethods;
typedef const struct _jc_org_xml_sax_helpers_NewInstance$vtable	_jc_org_xml_sax_helpers_NewInstance$vtable;
typedef const struct _jc_org_xml_sax_helpers_NewInstance$vtype	_jc_org_xml_sax_helpers_NewInstance$vtype;

// Class fields structure
struct _jc_org_xml_sax_helpers_NewInstance$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Thread;
	struct _jc_java_lang_Class$object	*class__24org__24xml__24sax__24helpers__24NewInstance;
};
extern _jc_org_xml_sax_helpers_NewInstance$fields_struct _jc_org_xml_sax_helpers_NewInstance$class_fields;

// Constructors
extern void _jc_org_xml_sax_helpers_NewInstance$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_helpers_NewInstance$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_org_xml_sax_helpers_NewInstance$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_lang_ClassLoader$object *_jc_org_xml_sax_helpers_NewInstance$method$getClassLoader$2078dc747ca30d6e(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_org_xml_sax_helpers_NewInstance$method$newInstance$29038c6392efb104(_jc_env *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_xml_sax_helpers_NewInstance$vmethods {
};

// Vtable
struct _jc_org_xml_sax_helpers_NewInstance$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_NewInstance$vmethods	org_xml_sax_helpers_NewInstance;
};

// Vtype
struct _jc_org_xml_sax_helpers_NewInstance$vtype {
	_jc_type			type;
	_jc_org_xml_sax_helpers_NewInstance$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_NewInstance$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_xml_sax_helpers_NewInstance$refs {
    _jc_org_xml_sax_helpers_NewInstance$sub_refs	org_xml_sax_helpers_NewInstance;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_helpers_NewInstance$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_helpers_NewInstance$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_NewInstance$sub_nonrefs	org_xml_sax_helpers_NewInstance;
};

// Object instance structure
struct _jc_org_xml_sax_helpers_NewInstance$object {
	_jc_org_xml_sax_helpers_NewInstance$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_helpers_NewInstance$vtype	*vtype;
	_jc_org_xml_sax_helpers_NewInstance$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_helpers_NewInstance$vtype _jc_org_xml_sax_helpers_NewInstance$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_helpers_NewInstance, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_helpers_NewInstance$class_object;

#endif	/* _JC_org_xml_sax_helpers_NewInstance_H_ */
